"""
model to hold data
"""
from PySide2.QtCore import QAbstractTableModel # type: ignore
from PySide2.QtCore import QModelIndex, Qt # type: ignore
from PySide2.QtGui import QColor # type: ignore


class ModelBanktran(QAbstractTableModel):
    """
    holds the data, gets and sets it
    """
    def __init__(self):
        """
        sets the data, including the column headings
        """
        super().__init__()
        self._data = [['a','b','c','d'],['aa','bb','cc','dd'],]
        self._horhead = ['col right', 'col center', 'col both', 'col none']

    # reimplement in subclass per QAbstractItemModel
    def parent(self, child=None):
        """
        single use class, no parents as it is table
        """
        return QModelIndex()

    def flags(self, index=None):
        """
        """
        flg = Qt.ItemIsSelectable | Qt.ItemIsEnabled
        return flg

    def index(self, rix, cix, role=None):
        """
        go from r/c to index
        """
        return self.createIndex(rix, cix)

    def data(self, index, role=Qt.EditRole):
        """
        return the data
        colorix is 1 based as 0 is False like the default False setting
        """
        if role in (Qt.EditRole, Qt.DisplayRole):
            return self._data[index.row()][index.column()]
        # elif role == Qt.BackgroundRole:
        #     return QColor('green')
        # elif role == Qt.ForegroundRole:
        #     return QColor('red')
        elif role == Qt.TextAlignmentRole:
            if index.column() == 0:
                align = Qt.AlignRight
            elif index.column() == 1:
                align = Qt.AlignVCenter
            elif index.column() == 2:
                align = Qt.AlignVCenter | Qt.AlignRight
            return align

    def headerData(self, section, orientation, role=Qt.DisplayRole):
        if orientation == Qt.Horizontal and role == Qt.DisplayRole:
            try:
                return self._horhead[section]
            except Exception:
                pass
        return super().headerData(section, orientation, role)

    def rowCount(self, index=None):
        """
        return the count
        """
        try:
            return len(self._data)
        except TypeError:
            return 0

    def columnCount(self, index=None):
        """
        return the count
        """
        try:
            return len(self._data[0])
        except TypeError:
            return 0
